from typing import Annotated

from asyncreq import request
from fastapi import APIRouter, Header, HTTPException

from src.api.config import API_AUTH
from src.api.schemas.auth import RefreshToken, Token
from src.api.schemas.user import UserLogin, UserMin, UserRegister

router = APIRouter()


@router.post("/register", response_model=UserMin)
async def register(user: UserRegister):
    (response, status, _) = await request(
        f"{API_AUTH}/register", "POST", json=user.model_dump()
    )
    if status < 200 or status > 204:
        raise HTTPException(status_code=status, detail=response)
    return response


@router.post("/login", response_model=Token)
async def login(user: UserLogin):
    (response, status, _) = await request(
        f"{API_AUTH}/login", "POST", json=user.model_dump()
    )
    if status < 200 or status > 204:
        raise HTTPException(status_code=status, detail=response)
    return response


@router.post("/refresh", response_model=Token)
async def refresh(token: RefreshToken):
    (response, status, _) = await request(
        f"{API_AUTH}/refresh", "POST", json=token.model_dump()
    )
    if status < 200 or status > 204:
        raise HTTPException(status_code=status, detail=response)
    return response


@router.get("/status", response_model=UserMin)
async def status(authorization: Annotated[str | None, Header()] = None):
    header = {"Authorization": authorization if authorization is not None else ""}
    (response, status, _) = await request(f"{API_AUTH}/status", "GET", headers=header)
    if status < 200 or status > 204:
        raise HTTPException(status_code=status, detail=response)
    return response
